#include <libint2.h>
#ifdef __cplusplus
extern "C" {
#endif
void _aB_D__0__K__1___TwoPRep_P__0__H__1___Ab__up_0(const Libint_t* inteval);
#ifdef __cplusplus
};
#endif
